@@ -20,20 +20,29 @@ OC.L10N.register(
     "Last name" : "Van",
     "Display name" : "Vertoonnaam",
     "Last modified" : "Laas gewysig",
+    "Save" : "Bewaar",
+    "Description" : "Beskrywing",
     "Invalid image" : "Ongeldige beeld",
     "Name" : "Naam",
     "Company" : "Maatskappy",
     "Title" : "Titel",
     "Cancel" : "Kanselleer",
     "New contact" : "Nuwe kontak",
+    "Search contacts …" : "Soek kontakte …",
+    "Pending" : "Hangend",
     "Select type" : "Kies tipe",
     "Select Date" : "Kies Datum",
     "Select option" : "Kies opsie",
     "Close" : "Sluit",
     "Import" : "Voer In",
     "Not grouped" : "Nie gegroepeer",
+    "User" : "Gebruiker",
+    "Group" : "Groep",
     "Email" : "E-pos",
     "Contact" : "Kontak",
+    "Admin" : "Admin",
+    "Owner" : "Eienaar",
+    "Users" : "Gebruikers",
     "Nickname" : "Bynaam",
     "Detailed name" : "Gedetailleerde naam",
     "Additional names" : "Addisionele name",
