@@ -5,19 +5,28 @@ OC.L10N.register(
     "All contacts" : "كل جهات الإتصال",
     "Contacts" : "جهات الاتصال",
     "Copy to full name" : "انسخ إلى الإسم الكامل",
+    "Add contacts" : "اضافة جهات اتصال",
+    "Loading …" : "جاري التحميل …",
     "Download" : "تحميل",
+    "Send email" : "إرسال بريد",
     "Groups" : "مجموعات",
     "Group name" : "إسم الفريق",
+    "Circles" : "جماعة",
     "Rename" : "تعديل الإسم",
     "Enabled" : "مفعلة",
     "Delete" : "حذف",
+    "Copied" : "نُسخت ",
     "Copy link" : "نسخ الرابط",
     "Share with users or groups" : "شارك مع مستخدمين او مجموعات",
+    "No users or groups" : "لا يوجد مستخدمين أو مجموعات",
     "can edit" : "يمكن التعديل",
     "First name" : "الإسم",
     "Last name" : "اللقب",
     "Display name" : "الاسم المعروض",
     "Last modified" : "آخر تعديل",
+    "Password protection" : "الحماية بكلمة السر",
+    "Save" : "Save",
+    "Description" : "الوصف",
     "Upload a new picture" : "تحميل صورة جديدة",
     "Choose from Files" : "اختر من الملفات",
     "Download picture" : "تنزيل الصورة",
@@ -35,12 +44,25 @@ OC.L10N.register(
     "Cancel" : "إلغاء",
     "Address book" : "دفتر العناوين",
     "New contact" : "جهة إتصال جديدة",
+    "Search contacts …" : "البحث عن جهات الإتصال",
     "No results" : "دون أية نتيجة",
+    "Personal circle" : "حلقة شخصية",
+    "Pending" : "معلّق",
+    "Select Date" : "اختر التاريخ ",
     "Select option" : "حدد الخيار",
     "Close" : "إغلاق",
     "Import" : "استيراد",
     "Not grouped" : "غير مصنف",
+    "Circle" : "دائرة ",
+    "User" : "المستخدم",
+    "Group" : "المجموعة",
     "Email" : "البريد الإلكترونى",
+    "Contact" : "التواصل",
+    "Member" : "عضو",
+    "Moderator" : "مشرِف",
+    "Admin" : "مدير",
+    "Owner" : "المالك",
+    "Users" : "المستخدمين:",
     "Nickname" : "كنية.\nلقب.",
     "Detailed name" : "الإسم بالتفصيل",
     "Additional names" : "الأسماء الإضافية",
