@@ -8,8 +8,11 @@ OC.L10N.register(
     "Copy to full name" : "Copiar a nombre completo",
     "Omit year" : "Omitir año",
     "Download" : "Descargar",
+    "Send email" : "Enviar correo electrónico",
     "Groups" : "Grupos",
     "Group name" : "Nombre del grupo",
+    "Circles" : "Círculos",
+    "Create a new circle" : "Crear un nuevo círculo",
     "Rename" : "Renombrar",
     "Enabled" : "Habilitado",
     "Delete" : "Borrar",
@@ -24,6 +27,9 @@ OC.L10N.register(
     "Display name" : "Nombre para mostrar",
     "Last modified" : "Última modificación",
     "Sort by {sorting}" : "Ordenar por {sorting}",
+    "Password protection" : "Protección con contraseña",
+    "Save" : "Guardar",
+    "Description" : "Descripción",
     "Add new property" : "Añadir nueva propiedad",
     "Choose property type" : "Elija el tipo de propiedad",
     "Upload a new picture" : "Subir una nueva imagen",
@@ -35,6 +41,7 @@ OC.L10N.register(
     "Name" : "Nombre",
     "Company" : "Empresa",
     "Title" : "Título",
+    "Generate QR Code" : "Generar código QR",
     "Cancel" : "Cancelar",
     "This contact is not yet synced. Edit it to save it to the server." : "Este contacto aún no está sincronizado. Edítalo para guardarlo en el servidor.",
     "This contact is in read-only mode. You do not have permission to edit this contact." : "Este contacto está en modo de sólo lectura. No tienes permiso para editar este contacto.",
@@ -42,7 +49,10 @@ OC.L10N.register(
     "Address book" : "libreta de direcciones",
     "New contact" : "Nuevo contacto",
     "The contact doesn't exists anymore on the server." : "El contacto ya no existe en el servidor.",
+    "Search contacts …" : "Buscar contactos ...",
     "No results" : "Sin resultados",
+    "Personal circle" : "Círculo personal",
+    "Pending" : "Pendiente",
     "Select type" : "Seleccionar tipo",
     "Select Date" : "Seleccionar fecha",
     "Add contact in group" : "Añadir contacto en grupo",
@@ -52,8 +62,16 @@ OC.L10N.register(
     "Close" : "Cerrar",
     "Import" : "Importar",
     "Not grouped" : "No agrupado",
+    "Circle" : "Círculo",
+    "User" : "Usuario",
+    "Group" : "Grupo",
     "Email" : "Correo electrónico",
     "Contact" : "Contacto",
+    "Member" : "Miembro",
+    "Moderator" : "Moderador",
+    "Admin" : "Administrador",
+    "Owner" : "Dueño",
+    "Users" : "Ususarios",
     "Nickname" : "Apodo",
     "Detailed name" : "Nombre detallado",
     "Additional names" : "Nombres adicionales",
@@ -110,4 +128,4 @@ OC.L10N.register(
     "None" : "Ninguno",
     "Unknown" : "Desconocido"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
