@@ -5,9 +5,12 @@ OC.L10N.register(
     "All contacts" : "تمام مخاطبین",
     "Contacts" : "مخاطبین",
     "Loading …" : "بارگذاری …",
+    "Delete circle" : "حذف حلقه",
     "Download" : "دانلود",
+    "Send email" : "ارسال ایمیل",
     "Groups" : "گروه ها",
     "Group name" : "نام گروه",
+    "Circles" : "حلقه ها",
     "Rename" : "تغییرنام",
     "Enabled" : "فعال شده",
     "Delete" : "حذف",
@@ -20,6 +23,9 @@ OC.L10N.register(
     "Last name" : "نام‌خانوادگی",
     "Display name" : "نام جهت نمایش",
     "Last modified" : "آخرین اصلاح شده",
+    "Password protection" : "محافظت از رمز عبور",
+    "Save" : "ذخیره",
+    "Description" : "توضیحات",
     "Invalid image" : "عکس نامعتبر",
     "Name" : "نام",
     "Company" : "شرکت",
@@ -27,13 +33,25 @@ OC.L10N.register(
     "Cancel" : "لغو",
     "Address book" : "دفترچه آدرس",
     "New contact" : "مخاطب جدید",
+    "Search contacts …" : "جستجو مخاطبین ...",
     "No results" : "نتیجه ای یافت نشد",
+    "Personal circle" : "حلقه شخصی",
+    "Pending" : "در انتظار",
     "Select Date" : "تاریخ را انتخاب کنید",
     "Close" : "بستن",
     "Import" : "وارد کردن",
     "Not grouped" : "گروه بندی نشده",
+    "Circle" : "حلقه",
+    "User" : "کاربر",
+    "Group" : "گروه",
     "Email" : "پست الکترونیکی",
     "Contact" : "مخاطب",
+    "Member" : "عضو",
+    "Moderator" : "مدیر",
+    "Admin" : "مدیر",
+    "Owner" : "مالک",
+    "Users" : "کاربران",
+    "Emails" : "ایمیل",
     "Nickname" : "نام مستعار",
     "Detailed name" : "نام کامل",
     "Additional names" : "نام های دیگر",
