@@ -5,9 +5,13 @@ OC.L10N.register(
     "All contacts" : "ყველა კონტაქტი",
     "Contacts" : "კონტაქტები",
     "Loading contacts …" : "კონტაქტების ჩატვირთვა ...",
+    "Delete circle" : "წრის გაუქმება",
     "Download" : "ჩამოტვირთვა",
+    "Send email" : "ელ-წერილის გაგზავნა",
     "Groups" : "ჯგუფები",
     "Group name" : "ჯგუფის სახელი",
+    "Circles" : "წრეები",
+    "Create a new circle" : "შექმენით წრე",
     "Rename" : "სახელის შეცვლა",
     "Enabled" : "მოქმედია",
     "Delete" : "გაუქმება",
@@ -18,18 +22,32 @@ OC.L10N.register(
     "Last name" : "გვარი",
     "Display name" : "დისპლეი სახელი",
     "Last modified" : "ბოლო ცვლილება",
+    "Password protection" : "პაროლით თავდაცვა",
+    "Save" : "შენახვა",
+    "Description" : "აღწერილობა",
     "Invalid image" : "არასწორი სურათი",
     "Name" : "სახელი",
     "Title" : "სათაური",
     "Cancel" : "უარყოფა",
     "Address book" : "მისამართების წიგნი",
     "New contact" : "ახალი კონტაქტი",
+    "Search contacts …" : "მოძებნეთ კონტაქტები ...",
     "No results" : "შედეგები არაა",
+    "Personal circle" : "პირადი წრე",
+    "Pending" : "მოლოდინში",
     "Close" : "დახურვა",
     "Import" : "იმპორტი",
     "Not grouped" : "არაა დაჯგუფებული",
+    "Circle" : "წრე",
+    "User" : "მომხმარებელი",
+    "Group" : "ჯგუფი",
     "Email" : "ელ-ფოსტა",
     "Contact" : "კონტაქტი",
+    "Member" : "წევრი",
+    "Moderator" : "მოდერატორი",
+    "Admin" : "ადმინისტრატორი",
+    "Owner" : "მფლობელი",
+    "Users" : "მომხმარებლები",
     "Nickname" : "ნიკნეიმი",
     "Detailed name" : "დეტალური სახელი",
     "Additional names" : "დამატებითი სახელები",
