@@ -2,18 +2,27 @@ OC.L10N.register(
     "contacts",
     {
     "Download" : "ಪ್ರತಿಯನ್ನು ಸ್ಥಳೀಯವಾಗಿ ಉಳಿಸಿಕೊಳ್ಳಿ",
+    "Send email" : "ಇ-ಅಂಚೆಯನ್ನು  ಕಳುಹಿಸಿ",
     "Groups" : "﻿ಗುಂಪುಗಳು",
     "Rename" : "﻿ಮರುಹೆಸರಿಸು",
     "Enabled" : "ಸಕ್ರಿಯಗೊಳಿಸಿದೆ",
     "Delete" : "﻿ಅಳಿಸಿ",
     "can edit" : "﻿ಸಂಪಾದಿಸಬಹುದು",
+    "Password protection" : "Password protection",
+    "Save" : "﻿ಉಳಿಸಿ",
     "Invalid image" : "ಅಸಾಮರ್ಥ್ಯ ಚಿತ್ರ",
     "Name" : "﻿ಹೆಸರು",
     "Title" : "ಶೀರ್ಷಿಕೆ",
     "Cancel" : "﻿ರದ್ದು",
+    "Pending" : "﻿ಬಾಕಿ ಇದೆ",
     "Close" : "ಮುಚ್ಚು",
     "Import" : "ಆಮದು",
+    "User" : "User",
+    "Group" : "﻿ಗುಂಪು",
     "Email" : "﻿ಇ-ಅಂಚೆ",
+    "Admin" : "﻿ನಿರ್ವಹಕ",
+    "Owner" : "Owner",
+    "Users" : "﻿ಬಳಕೆದಾರರು",
     "Notes" : "Notes",
     "Home" : "﻿ಮುಖಪುಟ",
     "Other" : "﻿ಇತರೆ",
