@@ -24,6 +24,7 @@ OC.L10N.register(
     "Leave circle" : "서클 떠나기",
     "Delete circle" : "서클 삭제",
     "Download" : "다운로드",
+    "Send email" : "이메일 보내기",
     "Groups" : "그룹",
     "Create a new group" : "새 그룹 생성",
     "Group name" : "그룹 이름",
@@ -67,6 +68,8 @@ OC.L10N.register(
     "Update avatars from social media" : "소셜 네트워크에서 아바타 업데이트",
     "(refreshed once per week)" : "(주 1회 새로고침)",
     "An error happened during the config change" : "변경 사항을 설정하는 중 오류 발생",
+    "Password protection" : "암호 보호",
+    "Save" : "저장",
     "Circle name" : "서클 이름",
     "Circle owned by {owner}" : "{owner} 님이 소유한 서클",
     "Request to join" : "등록 요청",
@@ -110,6 +113,7 @@ OC.L10N.register(
     "Unable to retrieve the contact from the server, please check your network connection." : "연락처를 가져올 수 없습니다. 네트워크 연결을 확인하세요.",
     "An error occurred while trying to move the contact" : "연락처를 이동하는 중 오류 발생",
     "An error occurred while trying to copy the contact" : "연락처를 복사하는 중 오류 발생",
+    "Search contacts …" : "연락처 검색…",
     "Add to {group}" : "{group}에 추가",
     "Remove {type}" : "{type} 삭제",
     "Search {types}" : "{types} 검색",
@@ -133,6 +137,7 @@ OC.L10N.register(
     "There was an issue adding members to the circle" : "서클에 회원을 추가하는 중 문제 발생",
     "Manage level" : "레벨 관리",
     "Remove member" : "회원 삭제",
+    "Pending" : "보류 중",
     "Promote as sole owner" : "단독 소유자 지정",
     "Promote to {level}" : "{level}(으)로 상향",
     "Demote to {level}" : "{level}(으)로 하향",
