@@ -7,12 +7,21 @@ OC.L10N.register(
     "Rename" : "Namakan",
     "Delete" : "Padam",
     "can edit" : "boleh mengubah",
+    "Password protection" : "Password protection",
+    "Save" : "Simpan",
+    "Description" : "Keterangan",
     "Name" : "Nama",
     "Title" : "Judul",
     "Cancel" : "Batal",
+    "Pending" : "Dalam proses",
     "Close" : "Tutup",
     "Import" : "Import",
+    "User" : "User",
+    "Group" : "Group",
     "Email" : "Email",
+    "Admin" : "Admin",
+    "Owner" : "Owner",
+    "Users" : "Pengguna",
     "Nickname" : "Nama Samaran",
     "Additional names" : "Nama tambahan",
     "Notes" : "Nota",
