@@ -8,13 +8,18 @@ OC.L10N.register(
     "Copy to full name" : "Kopier til fullt navn",
     "Loading contacts …" : "Laster inn kontakter…",
     "Loading …" : "Laster...",
+    "Delete circle" : "Slett sirkel",
     "Download" : "Last ned",
+    "Send email" : "Send e-post",
     "Groups" : "Grupper",
     "Group name" : "Gruppenavn",
+    "Circles" : "Sirkler",
+    "Create a new circle" : "Opprett en ny sirkel",
     "Rename" : "Gi nytt navn",
     "Enabled" : "Aktiver",
     "Delete" : "Slett",
     "Copied" : "Kopiert",
+    "Cannot copy" : "Kan ikke kopiere",
     "Copy link" : "Kopier lenke",
     "Share with users or groups" : "Del med brukere eller grupper",
     "No users or groups" : "Ingen brukere eller grupper",
@@ -24,6 +29,9 @@ OC.L10N.register(
     "Display name" : "Visningsnavn",
     "Last modified" : "Sist endret",
     "Sort by {sorting}" : "Sorter etter {sorting}",
+    "Password protection" : "Passordbeskyttelse",
+    "Save" : "Lagre",
+    "Description" : "Beskrivelse",
     "Add new property" : "Legg til felt",
     "Choose property type" : "Velg felttype",
     "Upload a new picture" : "Last opp et nytt bilde",
@@ -41,7 +49,10 @@ OC.L10N.register(
     "Address book" : "Adressebok",
     "New contact" : "Ny kontakt",
     "Syntax error. Cannot open the contact." : "Syntaksfeil. Kan ikke åpne kontakten.",
+    "Search contacts …" : "Søk etter kontakter…",
     "No results" : "Ingen resultater",
+    "Personal circle" : "Personlig sirkel",
+    "Pending" : "Venter",
     "Select type" : "Velg type",
     "Select Date" : "Velg dato",
     "Add contact in group" : "Legg kontakt til gruppe",
@@ -51,8 +62,17 @@ OC.L10N.register(
     "Close" : "Lukk",
     "Import" : "Importer",
     "Not grouped" : "Ikke gruppert",
+    "Circle" : "Sirkel",
+    "User" : "Bruker",
+    "Group" : "Gruppe",
     "Email" : "E-post",
     "Contact" : "Kontakt",
+    "Member" : "Medlem",
+    "Moderator" : "Moderator",
+    "Admin" : "Administrator",
+    "Owner" : "Eier",
+    "Users" : "Brukere",
+    "Emails" : "E-poster",
     "Nickname" : "Kallenavn",
     "Detailed name" : "Detaljert navn",
     "Additional names" : "Ev. mellomnavn",
