@@ -6,12 +6,17 @@ OC.L10N.register(
     "Contacts" : "Contacte",
     "Loading contacts …" : "Se încarcă contactele ...",
     "Loading …" : "Se încarcă…",
+    "Delete circle" : "Șterge cerc",
     "Download" : "Descărcare",
+    "Send email" : "Trimite email-ul",
     "Groups" : "Grupuri",
     "Group name" : "Numele grupului",
+    "Circles" : "Cercuri",
+    "Create a new circle" : "Crează un cerc nou",
     "Rename" : "Redenumește",
     "Enabled" : "Activat",
     "Delete" : "Șterge",
+    "Copied" : "Copiat",
     "Copy link" : "Copiază linkul",
     "Share with users or groups" : "Partajează cu utilizatori sau grupuri",
     "No users or groups" : "Nu sunt utilizatori sau grupuri",
@@ -19,18 +24,36 @@ OC.L10N.register(
     "First name" : "Prenume",
     "Last name" : "Nume",
     "Display name" : "Nume afișat",
+    "Password protection" : "Protecție parolă ",
+    "Save" : "Salvează",
+    "Description" : "Descriere",
     "Invalid image" : "Imagine invalidă",
     "Name" : "Nume",
+    "Company" : "Companie",
     "Title" : "Titlu",
     "Cancel" : "Anulează",
     "Address book" : "Listă de contacte",
     "New contact" : "Contact nou ",
+    "Search contacts …" : "Caută contacte ...",
     "No results" : "Niciun rezultat",
+    "Personal circle" : "Cerc personal",
+    "Pending" : "În așteptare",
+    "Select option" : "Selectatți opțiunea",
     "Close" : "Închide",
     "Import" : "Importă",
     "Not grouped" : "Negrupate",
+    "Recently contacted" : "Contactat recent",
+    "Circle" : "Cerc",
+    "User" : "Utilizator",
+    "Group" : "Grup",
     "Email" : "Email",
     "Contact" : "Contact",
+    "Member" : "Membru",
+    "Moderator" : "Moderator",
+    "Admin" : "Admin",
+    "Owner" : "Proprietar",
+    "Visibility" : "Vizibil",
+    "Users" : "Utilizatori",
     "Nickname" : "Pseudonim",
     "Detailed name" : "Nume detaliat",
     "Additional names" : "Nume adiționale",
