@@ -8,9 +8,13 @@ OC.L10N.register(
     "Copy to full name" : "Kopje të emrit të plotë ",
     "Omit year" : "Shmang vitin",
     "Loading contacts …" : "Duke ngarkuar kontaktet ...",
+    "Delete circle" : "Fshini rrethin",
     "Download" : "Shkarko",
+    "Send email" : "Dërgo email",
     "Groups" : "Grupe",
     "Group name" : "Emër grupi",
+    "Circles" : "Rrethet",
+    "Create a new circle" : "Krijo një rreth të ri",
     "Rename" : "Riemëro",
     "Enabled" : "I aktivizuar",
     "Delete" : "Fshije",
@@ -22,6 +26,9 @@ OC.L10N.register(
     "Last name" : "Mbiemër",
     "Display name" : "Shfaq emrin",
     "Last modified" : "Ndryshuar së fundmi",
+    "Password protection" : "Password protection",
+    "Save" : "Ruaj",
+    "Description" : "Përshkrim",
     "Add new property" : "Shto karakteristikë të re",
     "Choose property type" : "Zgjidh llojin e  karakteristikës",
     "Upload a new picture" : "Ngarko një foto të re",
@@ -39,6 +46,7 @@ OC.L10N.register(
     "Company" : "Kompania",
     "Title" : "Titulli",
     "This contact was broken and received a fix. Please review the content and click here to save it." : "Ky kontakt ishte prishur dhe u rregullua. Ju lutem rishikoni përmbajtjen dhe klikoni këtu për ta ruajtur atë.",
+    "Generate QR Code" : "Gjeneroni Kodin QR",
     "Cancel" : "Anullo",
     "This contact is not yet synced. Edit it to save it to the server." : "Ky kontakt nuk është sinkronizuar akoma. Përditësojeni atë për ta ruajtur në server.",
     "This contact is in read-only mode. You do not have permission to edit this contact." : "Ky kontakt është në gjendjen vetëm-lexo. Ju nuk keni të drejtë ta ndryshoni këtë kontakt.",
@@ -47,15 +55,26 @@ OC.L10N.register(
     "New contact" : "Kontakt i ri",
     "Syntax error. Cannot open the contact." : "Gabim sintakse. Kontakti nuk mund të hapet.",
     "The contact doesn't exists anymore on the server." : "Kontakti nuk ekziston më në server.",
+    "Search contacts …" : "Kërko kontakte ...",
     "No results" : "Asnjë rezultat",
+    "Personal circle" : "Rreth personal",
+    "Pending" : "Në Pritje të Konfirmimit",
     "Select type" : "Zgjidhni llojin",
     "Select Date" : "Zgjidhni Datën",
     "Add contact in group" : "Shto kontaktin në grup",
     "Close" : "Mbylleni",
     "Import" : "Import",
     "Not grouped" : "I pagrupuar",
+    "Circle" : "Rreth",
+    "User" : "Përdorues",
+    "Group" : "Grup",
     "Email" : "Email",
     "Contact" : "Kontakt",
+    "Member" : "Anëtar",
+    "Moderator" : "Moderator",
+    "Admin" : "Administrator",
+    "Owner" : "Zotëruesi",
+    "Users" : "Përdoruesit",
     "Nickname" : "Nofkë",
     "Detailed name" : "Emri i hollësishëm",
     "Additional names" : "Emra shtesë",
