@@ -8,13 +8,21 @@ OC.L10N.register(
     "Delete" : "Delete",
     "Copy link" : "Kopiraj vezu",
     "can edit" : "može da menja",
+    "Password protection" : "Password protection",
+    "Save" : "Sačuvaj",
+    "Description" : "Opis",
     "Name" : "naziv",
     "Title" : "Naslov",
     "Cancel" : "Otkaži",
     "No results" : "Nema rezultata",
+    "Pending" : "Na čekanju",
     "Close" : "Zatvori",
     "Import" : "Uvezi",
+    "User" : "Korisnik",
+    "Group" : "Group",
     "Email" : "email",
+    "Moderator" : "Moderator",
+    "Owner" : "Vlasnik",
     "Notes" : "Notes",
     "Website" : "Sajt",
     "Home" : "Почетна",
